@@ -27,17 +27,14 @@ from qubell.api.private.manifest import Manifest
 
 class ApplicationClassTest(BaseTestCase):
 
-    @classmethod
-    def setUpClass(cls):
-        super(ApplicationClassTest, cls).setUpClass()
-        cls.org = cls.organization
-        cls.app = cls.org.create_application(manifest=cls.manifest, name='Self-ApplicationClassTest')
-
-    @classmethod
-    def tearDownClass(cls):
-        cls.app.delete()
-        super(ApplicationClassTest, cls).tearDownClass()
+    def setup_once(self):
+        super(ApplicationClassTest, self).setup_once()
+        self.org = self.organization
+        self.app = self.org.create_application(manifest=self.manifest, name='Self-ApplicationClassTest')
 
+    def teardown_once(self):
+        self.app.delete()
+        super(ApplicationClassTest, self).teardown_once()
 
     def test_applications_sugar(self):
         org = self.org
@@ -62,7 +59,6 @@ class ApplicationClassTest(BaseTestCase):
 
         self.assertTrue(my_app.delete())
 
-
     def test_get_or_create_application_method(self):
         app = self.app
         org = self.org
@@ -77,7 +73,6 @@ class ApplicationClassTest(BaseTestCase):
         self.assertEqual(new_app.name, 'Self-get_or_create_application-test')
         self.assertTrue(new_app.delete())
 
-
     def test_smart_application_method(self):
         org = self.org
         app = self.app
@@ -108,7 +103,6 @@ class ApplicationClassTest(BaseTestCase):
         # Clean
         self.assertTrue(base_app.delete())
 
-
     def test_revision_create(self):
         app = self.app
 
